"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.FluidAppOdspUrlResolver = void 0;
const common_utils_1 = require("@fluidframework/common-utils");
const odsp_driver_1 = require("@fluidframework/odsp-driver");
const fluidOfficeAndOneNoteServers = [
    "dev.fluidpreview.office.net",
    "fluidpreview.office.net",
    "www.onenote.com",
];
class FluidAppOdspUrlResolver {
    async resolve(request) {
        const reqUrl = new URL(request.url);
        const server = reqUrl.hostname.toLowerCase();
        let contents;
        if (fluidOfficeAndOneNoteServers.includes(server)) {
            contents = await initializeFluidOfficeOrOneNote(reqUrl);
        }
        else if (server === "www.office.com") {
            const getRequiredParam = (name) => {
                const value = reqUrl.searchParams.get(name);
                (0, common_utils_1.assert)(!!value, 0x097 /* Missing param from office.com URL parameter */);
                return value;
            };
            contents = {
                driveId: getRequiredParam("drive"),
                itemId: getRequiredParam("item"),
                siteUrl: getRequiredParam("siteUrl"),
            };
        }
        else {
            return undefined;
        }
        if (!contents) {
            return undefined;
        }
        const urlToBeResolved = (0, odsp_driver_1.createOdspUrl)({ ...contents, dataStorePath: "" });
        const odspDriverUrlResolver = new odsp_driver_1.OdspDriverUrlResolver();
        return odspDriverUrlResolver.resolve({ url: urlToBeResolved });
    }
    // TODO: Issue-2109 Implement detach container api or put appropriate comment.
    async getAbsoluteUrl(resolvedUrl, relativeUrl, packageInfoSource) {
        throw new Error("Not implemented");
    }
}
exports.FluidAppOdspUrlResolver = FluidAppOdspUrlResolver;
async function initializeFluidOfficeOrOneNote(urlSource) {
    const pathname = urlSource.pathname;
    const siteDriveItemMatch = pathname.match(/\/(p|preview|meetingnotes|notes)\/([^/]*)\/([^/]*)\/([^/]*)/);
    if (siteDriveItemMatch === null) {
        return undefined;
    }
    const site = decodeURIComponent(siteDriveItemMatch[2]);
    // Path value is base64 encoded so need to decode first
    const decodedSite = (0, common_utils_1.fromBase64ToUtf8)(site);
    // Site value includes storage type
    const storageType = decodedSite.split(":")[0];
    const expectedStorageType = "spo"; // Only support spo for now
    if (storageType !== expectedStorageType) {
        throw new Error(`Unexpected storage type ${storageType}, expected: ${expectedStorageType}`);
    }
    // Since we have the drive and item, only take the host ignore the rest
    const siteUrl = decodedSite.substring(storageType.length + 1);
    const driveId = decodeURIComponent(siteDriveItemMatch[3]);
    const itemId = decodeURIComponent(siteDriveItemMatch[4]);
    return { siteUrl, driveId, itemId };
}
//# sourceMappingURL=urlResolver.js.map